/*
 * $Revision: 1.1.2.3 $
 */


/*
**  If you make local modifications to INN, change this line as needed:
*/
#define LOCAL_STRING	""


/*
**  Try to avoid changing these.
*/
#define RELEASE "2"
#define PATCHLEVEL "2.3"
#define DATE "18-Jul-2000"


/*
**  See lib/innvers.c, but the version string should look like this:
**	INN ${RELEASE}.${PATCHLEVEL} ${DATE} (${LOCAL_STRING})
**  for example:
**	INN 1.0 10-Feb-92 (FOO.COM)
*/
